@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 # shortcuts
 #  os and distros
@@ -17,6 +17,12 @@ use constant freebsd_jpeg => 'jpeg | jpeg-turbo';
 
 sub mapping {
     (
+     [cpanmod => 'AI::LibNeural',
+      [os_freebsd,
+       [package => 'libneural']], # but marked as broken (unfetchable)
+      # not available for debian or centos
+     ],
+
      [cpanmod => 'AI::PBDD',
       [os_freebsd,
        # but does not work, kernel.h is also required
@@ -41,6 +47,8 @@ sub mapping {
        [package => 'yasm']],
       [like_debian,
        [package => 'yasm']],
+      [like_fedora,
+       [package => 'yasm']],
      ],
 
      [cpanmod => 'Alien::FFTW3',
@@ -55,6 +63,17 @@ sub mapping {
       [like_debian,
        # "yasm/nasm not found or too old. Use --disable-yasm for a crippled build."
        [package => ['libhdf4-dev', 'yasm']]],
+      [like_fedora,
+       [package => 'hdf-devel']],
+     ],
+
+     [cpanmod => 'Alien::IUP',
+      [os_freebsd,
+       [package => [qw(gtk2 cairo freeglut)]]],
+      [like_debian,
+       [package => [qw(libgtk-3-dev libcairo2-dev libx11-dev libglu-dev freeglut3-dev)]]],
+      [like_fedora,
+       [package => [qw(gtk2-devel cairo-devel libX11-devel libGLU-devel freeglut-devel)]]],
      ],
 
      [cpanmod => 'Alien::LibUSBx',
@@ -88,6 +107,11 @@ sub mapping {
       [like_debian,
        [package => 'libprotobuf-dev']]],
 
+     [cpanmod => 'Alien::raylib',
+      [like_fedora,
+       [package => 'libXrandr-devel']],
+     ],
+
      [cpanmod => 'Alien::RRDtool',
       [os_freebsd,
        [package => ['pkgconf', 'glib', 'cairo', 'pango', 'libxml2']]],
@@ -103,7 +127,10 @@ sub mapping {
        # does not work, configure does not recognize sqlite
        [package => ['apr', 'sqlite3']]],
       [like_debian,
-       [package => ['libapr1-dev', 'libaprutil1-dev', 'libsqlite3-dev', 'zlib1g-dev']]]],
+       [package => ['libapr1-dev', 'libaprutil1-dev', 'libsqlite3-dev', 'zlib1g-dev']]],
+      [like_fedora,
+       [package => [qw(apr-devel apr-util-devel sqlite-devel)]]],
+     ],
 
      [cpanmod => 'Alien::unibilium',
       # XXX what about freebsd?
@@ -176,6 +203,12 @@ sub mapping {
       [like_debian,
        [package => 'libao-dev']]],
 
+     [cpanmod => 'Audio::Audiere',
+      [os_freebsd,
+       [package => 'audiere']], # but compilation failures
+      # no package for Debian & CentOS7
+     ],
+
      [cpanmod => 'Audio::Extract::PCM',
       # but does not work with freebsd, see https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=205732
       [package => 'sox']],
@@ -190,7 +223,10 @@ sub mapping {
       [os_freebsd,
        [package => 'gsm']],
       [like_debian,
-       [package => 'libgsm1-dev']]],
+       [package => 'libgsm1-dev']],
+      [like_fedora,
+       [package => 'gsm-devel']],
+     ],
 
      [cpanmod => 'Audio::LibSampleRate',
       [os_freebsd,
@@ -228,7 +264,10 @@ sub mapping {
       [os_freebsd,
        [package => ['libsndfile', 'pkgconf']]],
       [like_debian,
-       [package => 'libsndfile1-dev']]],
+       [package => 'libsndfile1-dev']],
+      [like_fedora,
+       [package => 'libsndfile-devel']],
+     ],
 
      [cpanmod => 'Audio::TagLib',
       [os_freebsd,
@@ -237,6 +276,17 @@ sub mapping {
        # but does not work, because the module wants taglib 1.9.1, but wheezy has 1.7.2-1
        [package => ['libtag1-dev', 'g++']]]],
 
+     [cpanmod => 'Authen::Krb5Password',
+      [os_freebsd,
+       [package => 'heimdal | krb5']],
+      [like_debian,
+       [linuxdistrocodename => [qw(squeeze wheezy jessie)],
+	[package => 'heimdal-dev | libkrb5-dev']],
+       [package => 'libkrb5-dev']],
+      [like_fedora,
+       [package => 'krb5-devel']],
+     ],
+
      [cpanmod => 'Authen::SASL::Cyrus',
       [os_freebsd,
        [package => 'cyrus-sasl']],
@@ -304,6 +354,11 @@ sub mapping {
       [os_darwin,
        [package => 'cairo']]],
 
+     [cpanmod => 'Cairo::GObject',
+      [like_fedora,
+       [package => 'cairo-gobject-devel']],
+     ],
+
      [cpanmod => 'Capstone',
       [os_freebsd,
        [package => 'capstone']],
@@ -315,7 +370,10 @@ sub mapping {
       [os_freebsd,
        [package => 'tinycdb']],
       [like_debian,
-       [package => 'libcdb-dev']]],
+       [package => 'libcdb-dev']],
+      [like_fedora,
+       [package => 'tinycdb-devel']],
+     ],
 
      [cpanmod => 'CDB_File::Generator',
       [os_freebsd,
@@ -334,6 +392,12 @@ sub mapping {
       [like_debian,
        [package => ['clamav-daemon', 'clamav-data']]]],
 
+     [cpanmod => 'Comedi::Lib',
+      # Not available for FreeBSD or CentOS7
+      [like_debian,
+       [package => 'libcomedi-dev']],
+     ],
+
      [cpanmod => ['Compress::LZMA::Simple', 'Compress::Raw::Lzma'],
       [os_freebsd,
        # this one does not work with Compress::Raw::Lzma under freebsd
@@ -362,7 +426,10 @@ sub mapping {
       [os_freebsd,
        [package => 'cracklib']],
       [like_debian,
-       [package => 'libcrack2-dev']]],
+       [package => 'libcrack2-dev']],
+      [like_fedora,
+       [package => 'cracklib-devel']],
+     ],
 
      [cpanmod => ['Crypt::DH::GMP', 'Math::GMPq', 'Math::GMPz', 'Math::BigInt::GMP'],
       [os_freebsd,
@@ -371,6 +438,8 @@ sub mapping {
        [linuxdistrocodename => 'squeeze',
 	[package => 'libgmp3-dev']],
        [package => 'libgmp-dev']],
+      [like_fedora,
+       [package => 'gmp-devel']],
       ## Does not work: "Symbol not found: ___gmp_randclear"
       ## Same problem with homebrew/versions/gmp4
       #[os_darwin,
@@ -392,12 +461,17 @@ sub mapping {
        [linuxdistrocodename => 'squeeze',
 	[package => []], # N/A in squeeze
        ],
-       [package => 'libmcrypt-dev']]],
+       [package => 'libmcrypt-dev']],
+      [like_fedora,
+       [package => [qw(libmcrypt-devel libtool-ltdl-devel)]]],
+     ],
 
-     [cpanmod => ['Crypt::OpenSSL::Random', 'Net::SSLeay', 'IO::Socket::SSL'],
+     [cpanmod => ['Crypt::OpenSSL::DSA', 'Crypt::OpenSSL::Random', 'Crypt::OpenSSL::X509', 'Net::SSLeay', 'IO::Socket::SSL'],
       # freebsd has all libssl in the base system
       [like_debian,
        [package => 'libssl-dev']],
+      [like_fedora,
+       [package => 'openssl-devel']],
       [os_windows,
        [package => 'openssl.light']]], # XXX create openssl.dev
 
@@ -421,6 +495,8 @@ sub mapping {
 	[package => []], # not available before jessie
        ],
        [package => 'libsodium-dev']],
+      [like_fedora,
+       [package => 'libsodium-devel']],
       [os_darwin,
        [package => 'libsodium']],
      ],
@@ -429,7 +505,10 @@ sub mapping {
       [os_freebsd,
        [package => ['libcroco', 'pkgconf']]],
       [like_debian,
-       [package => 'libcroco3-dev']]],
+       [package => 'libcroco3-dev']],
+      [like_fedora,
+       [package => 'libcroco-devel']],
+     ],
 
      [cpanmod => 'Curses',
       # ncurses.h is included in FreeBSD base install
@@ -438,7 +517,10 @@ sub mapping {
 
      [cpanmod => 'Curses::UI::Mousehandler::GPM',
       [like_debian,
-       [package => ['libgpm-dev', 'libncurses5-dev']]]],
+       [package => ['libgpm-dev', 'libncurses5-dev']]],
+      [like_fedora,
+       [package => ['gpm-devel']]],
+     ],
 
      [cpanmod => 'Database::Cassandra::Client',
       [os_freebsd,
@@ -451,13 +533,19 @@ sub mapping {
       [os_freebsd,
        [package => 'e2fsprogs-libuuid']],
       [like_debian,
-       [package => 'uuid-dev']]],
+       [package => 'uuid-dev']],
+      [like_fedora,
+       [package => 'libuuid-devel']],
+     ],
 
      [cpanmod => 'Date::LibICal',
       [os_freebsd,
        [package => 'libical']],
       [like_debian,
-       [package => 'libical-dev']]],
+       [package => 'libical-dev']],
+      [like_fedora,
+       [package => 'libical-devel']],
+     ],
 
      [cpanmod => 'DateLocale',
       [os_freebsd,
@@ -470,6 +558,8 @@ sub mapping {
        [package => 'mpfr']],
       [like_debian,
        [package => 'libmpfr-dev']],
+      [like_fedora,
+       [package => 'mpfr-devel']],
       ## Does not work:
       #[os_darwin,
       # [package => 'mpfr']],
@@ -489,13 +579,18 @@ sub mapping {
       [os_freebsd,
        [package => 'firebird25-server']],
       [like_debian,
-       [package => 'firebird-dev']]],
+       [package => 'firebird-dev']],
+      [like_fedora,
+       [package => 'firebird-devel']],
+     ],
 
      [cpanmod => 'DBD::mysql',
       [os_freebsd,
        [package => 'mysql-connector-c | mysql57-client | mysql56-client | mysql55-client | mariadb101-client | mariadb100-client | mariadb55-client | percona56-client | percona55-client']],
       [like_debian,
        [package => 'libmysqlclient-dev']],
+      [like_debian,
+       [package => 'mariadb-devel']],
       [os_darwin,
        [package => 'mysql-connector-c | mysql']],
      ],
@@ -510,7 +605,10 @@ sub mapping {
       [os_freebsd,
        [package => 'postgresql93-server']],
       [like_debian,
-       [package => 'libpq-dev']]],
+       [package => 'libpq-dev']],
+      [like_fedora,
+       [package => [qw(postgresql postgresql-devel)]]],
+     ],
 
      [cpanmod => 'Deliantra::Client',
       [os_freebsd,
@@ -550,13 +648,18 @@ sub mapping {
      [cpanmod => 'DLM::Client',
       # libdlm does not seem to exist on FreeBSD
       [like_debian,
-       [package => 'libdlm-dev']]],
+       [package => 'libdlm-dev']],
+      [like_fedora,
+       [package => 'dlm-devel']],
+     ],
      
      [cpanmod => 'DNS::LDNS',
       [os_freebsd,
        [package => 'ldns']],
       [like_debian,
        [package => 'libldns-dev']],
+      [like_fedora,
+       [package => 'ldns-devel']],
       # additionally needs to be patched, see https://github.com/eserte/srezic-cpan-distroprefs/blob/master/DNS-LDNS.yml
       [os_darwin,
        [package => 'ldns']]],
@@ -565,7 +668,10 @@ sub mapping {
       [os_freebsd,
        [package => 'libdvdread']],
       [like_debian,
-       [package => 'libdvdread-dev']]],
+       [package => 'libdvdread-dev']],
+      [like_fedora,
+       [package => 'libdvdread-devel']],
+     ],
 
      [cpanmod => 'EFL',
       [os_freebsd,
@@ -575,11 +681,19 @@ sub mapping {
        # here too: build is not successful anyway (Evas.h cannot be found)
        [package => ['libevas-dev', 'libelementary-dev']]]],
 
+     [cpanmod => 'Encode::TECkit',
+      [os_freebsd,
+       [package => 'teckit']],
+      # no package for Debian (jessie, stretch) and CentOS7
+     ],
+
      [cpanmod => 'EV::ADNS',
       [os_freebsd,
        [package => 'adns']],
       [like_debian,
-       [package => 'libadns1-dev']]],
+       [package => 'libadns1-dev']],
+      # no package available for CentOS7
+     ],
 
      [cpanmod => 'Event::Lib',
       [os_freebsd,
@@ -596,6 +710,8 @@ sub mapping {
       # XXX TBD FreeBSD: provided by gcc, which is in the base system for osvers < 10, and has to be installed separately for osvers >= 10
       [like_debian,
        [package => 'gfortran']],
+      [like_fedora,
+       [package => 'gcc-gfortran']],
       # XXX TBD MacOSX: "GNU Fortran is now provided as part of GCC, and can be installed with: brew install gcc"
      ],
 
@@ -604,8 +720,11 @@ sub mapping {
        [package => 'pkgconf']],
       [like_debian,
        [package => 'pkg-config | pkgconf']],
+      [like_fedora,
+       [package => 'pkgconfig']],
       [os_darwin,
-       [package => 'pkg-config']]],
+       [package => 'pkg-config']],
+     ],
 
      [cpanmod => 'File::ExtAttr',
       [like_debian,
@@ -618,6 +737,8 @@ sub mapping {
       # XXX what about freebsd?
       [like_debian,
        [package => 'libmagic-dev']],
+      [like_fedora,
+       [package => 'file-devel']],
       [os_darwin,
        [package => 'libmagic']]],
 
@@ -656,7 +777,10 @@ sub mapping {
      [cpanmod => 'Fuse',
       # Fuse.pm does not work on freebsd
       [like_debian,
-       [package => 'libfuse-dev']]],
+       [package => 'libfuse-dev']],
+      [like_fedora,
+       [package => 'fuse-devel']],
+     ],
 
      [cpanmod => 'Games::Chipmunk',
       [os_freebsd,
@@ -679,6 +803,17 @@ sub mapping {
        [package => 'libpoker-eval-dev']], # but does not build out of the box
      ],
 
+     [cpanmod => 'GCCJIT',
+      [like_debian,
+       [linuxdistrocodename => [qw(squeeze wheezy jessie precise)],
+	[package => []]], # N/A in older Debian+Ubuntu versions
+       [linuxdistrocodename => [qw(xenial)],
+	[package => 'libgccjit-5-dev']],
+       [linuxdistrocodename => [qw(stretch)],
+	[package => 'libgccjit-6-dev']],
+      ],
+     ],
+
      [cpanmod => 'GD',
       [os_freebsd,
        [package => 'libgd']],
@@ -696,7 +831,10 @@ sub mapping {
        [package => 'gearmand-devel'], # untested; not for small disks, needs boost-libs
       ],
       [like_debian,
-       [package => 'libgearman-dev']]],
+       [package => 'libgearman-dev']],
+      [like_fedora,
+       [package => 'libgearman-devel']],
+     ],
 
      [cpanmod => 'Geo::Hex::V3::XS',
       [package => 'cmake']],
@@ -706,6 +844,8 @@ sub mapping {
        [package => ['libproj4', 'proj']]],
       [like_debian,
        [package => ['libproj-dev', 'proj-bin']]],
+      [like_fedora,
+       [package => ['proj-devel', 'proj']]],
       [os_darwin,
        [package => 'proj']],
      ],
@@ -714,7 +854,10 @@ sub mapping {
       [os_freebsd,
        [package => 'shapelib']],
       [like_debian,
-       [package => 'libshp-dev']]],
+       [package => 'libshp-dev']],
+      [like_fedora,
+       [package => 'shapelib-devel']],
+     ],
 
      [cpanmod => ['Gimp', 'Alien::Gimp'],
       [os_freebsd,
@@ -743,7 +886,10 @@ sub mapping {
       [like_debian,
        [linuxdistrocodename => ['squeeze', 'wheezy'],
 	[package => []]], # N/A
-       [package => 'libgit2-dev']]],
+       [package => 'libgit2-dev']],
+      [like_fedora,
+       [package => 'libgit2-devel']],
+     ],
 
      [cpanmod => 'Glib',
       [like_fedora,
@@ -766,13 +912,19 @@ sub mapping {
       [os_freebsd,
        [package => 'libgnomecanvas']],
       [like_debian,
-       [package => 'libgnomecanvas2-dev']]],
+       [package => 'libgnomecanvas2-dev']],
+      [like_fedora,
+       [package => 'libgnomecanvas-devel']],
+     ],
 
      [cpanmod => 'Gnome2::GConf',
       [os_freebsd,
        [package => 'gconf2']],
       [like_debian,
-       [package => 'libgconf2-dev']]],
+       [package => 'libgconf2-dev']],
+      [like_fedora,
+       [package => 'GConf2-devel']],
+     ],
 
      [cpanmod => 'Gnome2::Wnck',
       [os_freebsd,
@@ -797,7 +949,10 @@ sub mapping {
       [os_freebsd,
        [package => 'goocanvas']],
       [like_debian,
-       [package => 'libgoocanvas-dev']]],
+       [package => 'libgoocanvas-dev']],
+      [like_fedora,
+       [package => 'goocanvas-devel']],
+     ],
 
      [cpanmod => 'Google::ProtocolBuffers::Dynamic',
       [os_freebsd,
@@ -814,11 +969,23 @@ sub mapping {
       [like_debian,
        [package => 'libplot-dev']]],
 
+     [cpanmod => 'Graphics::PLplot',
+      [os_freebsd,
+       [package => 'plplot']],
+      [like_debian,
+       [package => 'libplplot-dev']],
+      [like_fedora,
+       [package => 'plplot-devel']],
+     ],
+
      [cpanmod => ['Graphics::SANE', 'Sane'],
       [os_freebsd,
        [package => 'sane-backends']],
       [like_debian,
-       [package => 'libsane-dev']]],
+       [package => 'libsane-dev']],
+      [like_fedora,
+       [package => 'sane-backends-devel']],
+     ],
 
      [cpanmod => ['GraphViz', 'GraphViz2', 'GraphViz2::Marpa'],
       # package named the same in freebsd, debian and macosx/homebrew, maybe everywhere?
@@ -832,7 +999,29 @@ sub mapping {
      [cpanmod => 'Gtk2',
       # XXX freebsd?
       [like_debian,
-       [package => 'libgtk2.0-dev']]],
+       [package => 'libgtk2.0-dev']],
+      [like_fedora,
+       [package => 'gtk2-devel']],
+     ],
+
+     [cpanmod => 'Gtk2::GladeXML',
+      [os_freebsd,
+       [package => 'libglade2']],
+      [like_debian,
+       [package => 'libglade2-dev']],
+      [like_fedora,
+       [package => 'libglade2-devel']],
+     ],
+
+     [cpanmod => 'Gtk2::GLExt',
+      # But does not build anywhere...
+      [os_freebsd,
+       [package => 'gtkglext']],
+      [like_debian,
+       [package => 'libgtkglext1-dev']],
+      [like_fedora,
+       [package => 'gtkglext-devel']],
+     ],
 
      [cpanmod => 'Gtk2::ImageView',
       [os_freebsd,
@@ -840,12 +1029,33 @@ sub mapping {
       [like_debian,
        [package => 'libgtkimageview-dev']]],
 
+     [cpanmod => 'Gtk2::Spell',
+      [os_freebsd,
+       [package => 'gtkspell']],
+      [like_debian,
+       [package => 'libgtkspell-dev']],
+      [like_fedora,
+       [package => 'gtkspell-devel']],
+     ],
+
+     [cpanmod => 'Gtk2::Unique',
+      [os_freebsd,
+       [package => 'unique']],
+      [like_debian,
+       [package => 'libunique-dev']],
+      [like_fedora,
+       [package => 'unique-devel']],
+     ],
+
      [cpanmod => 'Gtk3',
       [os_freebsd,
        # additionally dbus has to be enabled and started
        [package => ['gtk3', 'dbus']]],
       [like_debian,
-       [package => 'libgtk-3-dev']]],
+       [package => 'libgtk-3-dev']],
+      [like_fedora,
+       [package => 'gtk3-devel']],
+     ],
 
      [cpanmod => 'Gtk3::SourceView',
       [os_freebsd,
@@ -871,7 +1081,11 @@ sub mapping {
        [package => 'heimdal']],
       [like_debian,
        # conflicts with libkrb5-dev
-       [package => 'heimdal-dev']]],
+       [package => 'heimdal-dev']],
+      [like_fedora,
+       # but does not build
+       [package => 'heimdal-devel']],
+     ],
 
      [cpanmod => 'Hiredis::Raw',
       [os_freebsd,
@@ -928,7 +1142,10 @@ sub mapping {
       [os_freebsd,
        [package => 'imlib2']],
       [like_debian,
-       [package => 'libimlib2-dev']]],
+       [package => 'libimlib2-dev']],
+      [like_fedora,
+       [package => 'imlib2-devel']],
+     ],
 
      [cpanmod => 'Image::LibExif',
       [os_freebsd,
@@ -946,7 +1163,10 @@ sub mapping {
       [os_freebsd,
        [package => 'librsvg2']],
       [like_debian,
-       [package => 'librsvg2-dev']]],
+       [package => 'librsvg2-dev']],
+      [like_fedora,
+       [package => 'librsvg2-devel']],
+     ],
 
      [cpanmod => 'Image::Magick',  # typically needs manual work
       [os_freebsd,
@@ -976,7 +1196,11 @@ sub mapping {
       [os_freebsd,
        [package => ['png', freebsd_jpeg]]],
       [like_debian,
-       [package => [qw(libjpeg-dev libpng12-dev)]]]],
+       [linuxdistrocodename => [qw(squeeze wheezy jessie precise xenial)],
+	[package => [qw(libjpeg-dev libpng12-dev)]]],
+       [package => [qw(libjpeg-dev libpng-dev)]],
+      ],
+     ],
 
      [cpanmod => 'Image::SubImageFind',
       # XXX what about freebsd?
@@ -987,9 +1211,12 @@ sub mapping {
       [os_freebsd,
        [package => [qw(freetype2 giflib png tiff), freebsd_jpeg]]], # in former days giflib-nox11 had to be specified
       [like_debian,
-       [linuxdistrocodename => ['wheezy', 'precise'],
+       [linuxdistrocodename => [qw(wheezy precise)],
 	[package => [qw(libfreetype6-dev libgif-dev libpng12-dev libjpeg-dev), 'libtiff5-dev | libtiff4-dev']]],
-       [package => [qw(libfreetype6-dev libgif-dev libpng12-dev libjpeg-dev libtiff5-dev)]]],
+       [linuxdistrocodename => [qw(jessie xenial)],
+	[package => [qw(libfreetype6-dev libgif-dev libpng12-dev libjpeg-dev libtiff5-dev)]]],
+       [package => [qw(libfreetype6-dev libgif-dev libpng-dev libjpeg-dev libtiff5-dev)]],
+      ],
       [like_fedora,
        [package => [qw(freetype-devel giflib-devel libpng-devel libjpeg-turbo-devel libtiff-devel)]]],
       [os_darwin,
@@ -1004,8 +1231,7 @@ sub mapping {
       [like_debian,
        linuxdistrocodename => [qw(squeeze wheezy)],
        [package => 'libt1-dev']],
-      # not available anymore since jessie
-      # XXX TBD how's the state in Ubuntu?
+      # not available anymore since jessie, also not in xenial
      ],
 
      # modules just needing java and nothing else:
@@ -1014,8 +1240,13 @@ sub mapping {
        [package => 'openjdk8']],
       [like_debian,
        [linuxdistrocodename => 'squeeze',
-	[package =>  'openjdk-6-jdk']],
-       [package => 'openjdk-7-jdk']]],
+	[package => 'openjdk-6-jdk']],
+       [linuxdistrocodename => [qw(wheezy jessie precise)],
+	[package => 'openjdk-7-jdk']],
+       [linuxdistrocodename => [qw(stretch xenial)],
+	[package => 'openjdk-8-jdk']],
+      ],
+     ],
 
      [cpanmod => 'Inline::Lua',
       [os_freebsd,
@@ -1036,7 +1267,10 @@ sub mapping {
       [like_debian,
        [linuxdistrocodename => ['squeeze', 'wheezy'],
 	[package => 'ruby1.8-dev']],
-       [package => 'ruby2.1-dev']]],
+       [package => 'ruby2.1-dev']],
+      [like_fedora,
+       [package => 'ruby-devel']],
+     ],
 
      [cpanmod => 'IPC::MMA',
       [os_freebsd,
@@ -1044,10 +1278,27 @@ sub mapping {
       [like_debian,
        [package => 'libmm-dev']]],
 
+     [cpanmod => 'IPC::XPA',
+      # no package for FreeBSD or CentOS7
+      [like_debian,
+       [package => 'libxpa-dev']],
+     ],
+
+     [cpanmod => 'IPTables::libiptc',
+      # Does not work with modern Linux distributions:
+      # https://rt.cpan.org/Ticket/Display.html?id=111267
+      [like_debian,
+       [package => 'iptables-dev']],
+      [like_fedora,
+       [package => 'iptables-devel']],
+     ],
+
      [cpanmod => 'JavaScript::V8',
       [os_freebsd,
        [package => 'v8']],
       # XXX what about debian?
+      [like_fedora,
+       [package => 'v8-devel']], # but problems with Devel-CheckLib and compilation errors
       [os_darwin,
        [package => 'v8']], # but compilation errors (v8-5.0.71.33 <-> JavaScript-V8-0.07)
      ],
@@ -1057,6 +1308,8 @@ sub mapping {
        [package => 'jq']],
       [like_debian,
        [package => 'jq']],
+      [like_fedora,
+       [package => 'jq']],
       [os_darwin,
        [package => 'jq']],
      ],
@@ -1072,7 +1325,10 @@ sub mapping {
      [cpanmod => 'Kernel::Keyring',
       # linux-only
       [like_debian,
-       [package => 'libkeyutils-dev']]],
+       [package => 'libkeyutils-dev']],
+      [like_fedora,
+       [package => 'keyutils-libs-devel']],
+     ],
 
      # XXX needs verification; maybe more latex-related modules should be listed here?
      [cpanmod => ['LaTeX::Driver', 'Template::Plugin::Latex'],
@@ -1109,7 +1365,10 @@ sub mapping {
 
      [cpanmod => 'Linux::ACL',
       [like_debian,
-       [package => 'libacl1-dev']]],
+       [package => 'libacl1-dev']],
+      [like_fedora,
+       [package => 'libacl-devel']],
+     ],
 
      [cpanmod => 'Linux::Inotify2',
       ## This inotify package is not able to run
@@ -1122,22 +1381,29 @@ sub mapping {
 
      [cpanmod => 'Linux::Netfilter::Log',
       [like_debian,
-       [package => 'libnetfilter-log-dev']]],
+       [package => 'libnetfilter-log-dev']],
+      [like_fedora,
+       [package => 'libnetfilter_log-devel']],
+     ],
 
      [cpanmod => 'Linux::Prctl',
       [like_debian,
-       [package => 'libcap-dev']]],
+       [package => 'libcap-dev']],
+      [like_fedora,
+       [package => 'libcap-devel']],
+     ],
 
      [cpanmod => 'Linux::Sysfs',
       [like_debian,
        [package => 'libsysfs-dev']]],
 
-     [cpanmod => 'Linux::Systemd::Journal',
+     [cpanmod => ['Linux::Systemd::Journal', 'Log::Journald'],
       [like_debian,
        [linuxdistrocodename => ['squeeze', 'wheezy', 'jessie'],
 	[package => 'libsystemd-journal-dev']],
-       # sid and probably stretch
-       [package => 'libsystemd-dev']]],
+       # sid, stretch and xenial
+       [package => 'libsystemd-dev']],
+     ],
 
      [cpanmod => 'LMDB_File',
       [os_freebsd,
@@ -1170,7 +1436,10 @@ sub mapping {
       [like_debian,
        [linuxdistrocodename => ['squeeze', 'wheezy'],
 	[package => []]],
-       [package => 'libopendmarc-dev']]],
+       [package => 'libopendmarc-dev']],
+      [like_fedora,
+       [package => 'libopendmarc-devel']],
+     ],
 
      [cpanmod => 'Mail::OpenDKIM',
       [os_freebsd,
@@ -1182,7 +1451,10 @@ sub mapping {
       [os_freebsd,
        [package => 'fftw3']],
       [like_debian,
-       [package => 'libfftw3-dev']]],
+       [package => 'libfftw3-dev']],
+      [like_fedora,
+       [package => 'fftw-devel']],
+     ],
 
      [cpanmod => 'Math::GammaFunction',
       [os_freebsd,
@@ -1201,6 +1473,8 @@ sub mapping {
        [package => 'gsl']],
       [like_debian,
        [package => 'libgsl0-dev']],
+      [like_fedora,
+       [package => 'gsl-devel']],
       [os_darwin,
        [package => 'gsl']],
      ],
@@ -1209,7 +1483,10 @@ sub mapping {
       [os_freebsd,
        [package => 'mpc']],
       [like_debian,
-       [package => 'libmpc-dev']]],
+       [package => 'libmpc-dev']],
+      [like_fedora,
+       [package => 'libmpc-devel']],
+     ],
 
      [cpanmod => 'Math::MPFI',
       # XXX what about freebsd?
@@ -1224,9 +1501,13 @@ sub mapping {
 
      [cpanmod => 'MaxMind::DB::Reader::XS',
       [os_freebsd,
-       # but tests fail
        [package => 'libmaxminddb']],
-      # XXX what about debian?
+      [like_debian,
+       [linuxdistrocodename => [qw(squeeze wheezy jessie precise)],
+	package => []], # N/A
+       [package => 'libmaxminddb-dev']], # xenian (but too old), stretch (works)
+      [like_fedora,
+       [package => 'libmaxminddb-devel']], # works
      ],
 
      [cpanmod => 'Mhash',
@@ -1247,7 +1528,10 @@ sub mapping {
       [os_freebsd,
        [package => 'id3lib']],
       [like_debian,
-       [package => 'libid3-3.8.3-dev']]],
+       [package => 'libid3-3.8.3-dev']],
+      [like_fedora,
+       [package => 'id3lib-devel']],
+     ],
 
      [cpanmod => 'modperl2',
       # XXX what about freebsd?
@@ -1299,18 +1583,33 @@ sub mapping {
       [like_debian,
        [package => 'libloudmouth1-dev']]],
 
+     [cpanmod => 'Net::LDAPxs',
+      [os_freebsd,
+       [package => 'ldapsdk']], # but package seems to be broken and unmaintained
+      [like_debian,
+       [package => 'libldap2-dev']],
+      [like_fedora,
+       [package => 'openldap-devel']],
+     ],
+     
      [cpanmod => 'Net::Libdnet',
       [os_freebsd,
        [package => 'libdnet']],
       [like_debian,
        # but does not work without applying the patch manually - see https://rt.cpan.org/Ticket/Display.html?id=106021
-       [package => 'libdumbnet-dev']]],
+       [package => 'libdumbnet-dev']],
+      [like_fedora,
+       [package => 'libdnet-devel']],
+     ],
 
      [cpanmod => 'Net::LibIDN',
       [os_freebsd,
        [package => 'libidn']],
       [like_debian,
-       [package => 'libidn11-dev']]],
+       [package => 'libidn11-dev']],
+      [like_fedora,
+       [package => 'libidn-devel']],
+     ],
 
      [cpanmod => 'Net::NfDump',
       [like_debian,
@@ -1326,20 +1625,19 @@ sub mapping {
      [cpanmod => 'Net::LibNIDS',
       [os_freebsd,
        # but does not work (no libnids.so in freebsd port, just .a)
-       [package => ['libnids', 'libnet']]],
+       [package => ['libnids', 'libnet', 'libpcap']]],
       [like_debian,
-       [package => ['libnids-dev', 'libnet1-dev']]]],
-
-     [cpanmod => 'Net::LibNIDS',
-      [os_freebsd,
-       # but does not work
-       [package => ['libpcap', 'libnids']]],
-      [like_debian,
-       [package => 'libpcap0.8-dev']]],
+       [package => ['libnids-dev', 'libnet1-dev', 'libpcap0.8-dev']]],
+      [like_fedora,
+       [package => ['libnids-devel', 'libnet-devel', 'libpcap-devel']]],
+     ],
 
      [cpanmod => 'Net::Pcap',
       [like_debian,
-       [package => 'libpcap0.8-dev']]],
+       [package => 'libpcap0.8-dev']],
+      [like_fedora,
+       [package => 'libpcap-devel']],
+     ],
 
      [cpanmod => 'Net::oRTP',
       [os_freebsd,
@@ -1352,6 +1650,8 @@ sub mapping {
        [package => 'rabbitmq-c-devel']],
       [like_debian,
        [package => 'librabbitmq-dev']], # amqp_tcp_socket.h is provided by this package, but compilation still fails
+      [like_fedora,
+       [package => 'librabbitmq-devel']],
      ],
 
      [cpanmod => 'Net::SIGTRAN::SCTP',
@@ -1370,6 +1670,8 @@ sub mapping {
        [package => 'libssh2']],
       [like_debian,
        [package => 'libssh2-1-dev']],
+      [like_fedora,
+       [package => 'libssh2-devel']],
       # Net-SSH2-0.58 already installs the homebrew package for libssh2 itself
      ],
 
@@ -1405,13 +1707,19 @@ sub mapping {
       [os_freebsd,
        [package => 'libvorbis']],
       [like_debian,
-       [package => 'libvorbis-dev']]],
+       [package => 'libvorbis-dev']],
+      [like_fedora,
+       [package => 'libvorbis-devel']],
+     ],
 
      [cpanmod => 'Ogg::Vorbis::Header',
       [os_freebsd,
        [package => 'libogg']],
       [like_debian,
-       [package => ['libogg-dev', 'libvorbis-dev']]]],
+       [package => ['libogg-dev', 'libvorbis-dev']]],
+      [like_fedora,
+       [package => ['libogg-devel', 'libvorbis-devel']]],
+     ],
 
      [cpanmod => 'OIS',
       ## ois in freebsd ports is 1.2.0, but 1.3.0 is required
@@ -1475,7 +1783,9 @@ sub mapping {
       [os_freebsd,
        [package => 'pgplot']],
       [like_debian,
-       [package => 'pgplot5']]],
+       [package => 'pgplot5']],
+      # no pgplot package for CentOS7
+     ],
 
      [cpanmod => 'Pod::Spelling',
       # XXX what about freebsd?
@@ -1494,7 +1804,11 @@ sub mapping {
      [cpanmod => 'Prima',
       # XXX what about freebsd?
       [like_debian,
-       [package => [qw(libx11-dev libxpm-dev libgif-dev libpng12-dev libjpeg-dev), 'pkg-config | pkgconf']]]], # XXX maybe also add libtiff...
+       [linuxdistrocodename => [qw(squeeze wheezy jessie precise xenial)],
+	[package => [qw(libx11-dev libxpm-dev libgif-dev libpng12-dev libjpeg-dev), 'pkg-config | pkgconf']]], # XXX maybe also add libtiff...
+       [package => [qw(libx11-dev libxpm-dev libgif-dev libpng-dev libjpeg-dev), 'pkg-config | pkgconf']], # XXX maybe also add libtiff...
+      ],
+     ],
 
      [cpanmod => 'PulseAudio',
       [package => 'pulseaudio']],
@@ -1515,13 +1829,25 @@ sub mapping {
       [like_debian,
        [linuxdistrocodename => ['squeeze', 'wheezy'],
 	[package => 'libxmlrpc-c3-dev']],
-       [package => 'libxmlrpc-core-c3-dev']]],
+       [package => 'libxmlrpc-core-c3-dev']],
+      [like_fedora,
+       [package => 'xmlrpc-c-devel']],
+     ],
 
 #	## various rpm using tools --- XXX which one exactly?
 #	## XXX disabled because package was not yet built (last check 2014-08-10)
 #	## see http://portsmon.freebsd.org/portoverview.py?category=archivers&portname=rpm5
 #	#package { "rpm5": ensure => installed }
 
+     [cpanmod => 'RRD::Tweak',
+      [os_freebsd,
+       [package => 'rrdtool']],
+      [like_debian,
+       [package => 'librrd-dev']],
+      [like_fedora,
+       [package => 'rrdtool-devel']],
+     ],
+
      [cpanmod => 'Search::Namazu',
       [os_freebsd,
        [package => 'namazu3']],
@@ -1578,7 +1904,7 @@ sub mapping {
        ],
        [package => 'couchdb']]],
 
-     [cpanmod => ['SVN::Hooks', 'SVN::Agent'], # XXX maybe more SVN::* modules?
+     [cpanmod => ['SVN::Hooks', 'SVN::Agent', 'SVN::S4'], # XXX maybe more SVN::* modules?
       [package => 'subversion']],
 
      [cpanmod => 'Sword',
@@ -1614,7 +1940,10 @@ sub mapping {
       [os_freebsd,
        [package => 'tcl86 | tcl85 | tcl84']],
       [like_debian,
-       [package => 'tcl8.5-dev']]],
+       [package => 'tcl8.5-dev']],
+      [like_fedora,
+       [package => 'tcl-devel']],
+     ],
 
      [cpanmod => 'Tcl::pTk',
       [os_freebsd,
@@ -1655,12 +1984,22 @@ sub mapping {
 	[package => []]],
        [package => 'libvterm-dev']]],
 
+     [cpanmod => 'Text::AI::CRM114',
+      [os_freebsd,
+       [package => 'libcrm114']],
+      # No package available for Debian or CentOS7
+     ],
+
      [cpanmod => 'Text::Aspell',
       [os_freebsd,
-       [# "aspell" alone is not enough, test needs also English direcotries
+       [# "aspell" alone is not enough, test needs also English dictionary
 	package => ['aspell', 'en-aspell']]],
       [like_debian,
-       [package => 'libaspell-dev']]],
+       [package => 'libaspell-dev']],
+      [like_fedora,
+       [# test needs also English dictionary
+	package => ['aspell-devel', 'aspell-en']]],
+     ],
 
      [cpanmod => 'Text::Bidi',
       # otherwise real tests are skipped
@@ -1748,7 +2087,11 @@ sub mapping {
        [package => 'libstatgrab']],
       [like_debian,
        # unfortunately does not work in wheezy, the library version is too old for the module
+       # jessie and later is fine
        [package => 'libstatgrab-dev']],
+      [like_fedora,
+       # package found in CentOS7 is probably too old
+       [package => 'libstatgrab-devel']],
       [os_darwin,
        [package => 'libstatgrab']]],
 
@@ -1774,6 +2117,15 @@ sub mapping {
        [package => 'wordnet']],
       [like_debian,
        [package => 'wordnet-base']],
+      [like_fedora,
+       [package => 'wordnet']],
+     ],
+
+     [cpanmod => 'WordNet::SenseKey',
+      [os_freebsd,
+       [package => 'wordnet']],
+      [like_debian,
+       [package => 'wordnet-sense-index']],
      ],
 
      [cpanmod => 'WWW::Bootstrap',
@@ -1804,6 +2156,7 @@ sub mapping {
       [os_freebsd,
        [package => 'wx30-gtk2']],
       # XXX what about debian?
+      # fedora: no package needed (e.g wxGTK-devel or wxGTK3-devel), works with Alien::wxWidgets
      ],
 
      [cpanmod => 'XML::LibXML',
